/***************************************************************************
                          newtemplatedirdlg.cpp  -  description
                             -------------------
    begin                : Fri Jun 21 2002
    copyright            : (C) 2002 by Andras Mantia <amantia@kde.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2 of the License.               *
 *                                                                         *
 ***************************************************************************/

#include <tqpushbutton.h>
#include "newtemplatedirdlg.h"
#include "newtemplatedirdlg.moc"

NewTemplateDirDlg::NewTemplateDirDlg(TQWidget *parent, const char *name ) : TemplateDirForm(parent,name)
{
  setCaption(name);
  connect( buttonOk, TQ_SIGNAL(clicked()), TQ_SLOT(accept()) );
  connect( buttonCancel, TQ_SIGNAL(clicked()), TQ_SLOT(reject()) );
}

NewTemplateDirDlg::~NewTemplateDirDlg()
{
}
